@@ -2,7 +2,6 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
 import os
@@ -65,9 +64,13 @@ from pcs.lib.external import (
     _service,
     _systemctl,
 )
+from pcs.lib.communication.nodes import (
+    availability_checker_node,
+    PrecheckNewNode,
+)
+from pcs.lib.communication.tools import run as run_com_cmd
 import pcs.lib.corosync.config_parser as corosync_conf_parser
 from pcs.lib.corosync.config_facade import ConfigFacade as corosync_conf_facade
-from pcs.lib.nodes_task import check_can_add_node_to_cluster
 from pcs.lib.pacemaker.live import has_wait_for_idle_support
 from pcs.lib.pacemaker.state import ClusterState
 from pcs.lib.pacemaker.values import(
@@ -117,9 +120,8 @@ def checkAndUpgradeCIB(major,minor,rev):
     cmajor, cminor, crev = getValidateWithVersion(get_cib_dom())
     if cmajor > major or (cmajor == major and cminor > minor) or (cmajor == major and cminor == minor and crev >= rev):
         return False
-    else:
-        cluster_upgrade()
-        return True
+    cluster_upgrade()
+    return True
 
 def cluster_upgrade():
     output, retval = run(["cibadmin", "--upgrade", "--force"])
@@ -230,11 +232,17 @@ def remove_uid_gid_file(uid,gid):
     return file_removed
 # Returns a dictionary {'nodeA':'tokenA'}
 def readTokens():
-    tokens = {}
+    return read_token_file()["tokens"]
+
+def read_token_file():
+    data = {
+        "tokens": {},
+        "ports": {},
+    }
     output, retval = run_pcsdcli("read_tokens")
     if retval == 0 and output['status'] == 'ok' and output['data']:
-        tokens = output['data']
-    return tokens
+        data = output['data']
+    return data
 
 def repeat_if_timeout(send_http_request_function, repeat_count=15):
     def repeater(node, *args, **kwargs):
@@ -274,8 +282,14 @@ def getPacemakerNodeStatus(node):
         node, "remote/pacemaker_node_status", None, False, False
     )
 
-def startCluster(node, quiet=False):
-    return sendHTTPRequest(node, 'remote/cluster_start', None, False, not quiet)
+def startCluster(node, quiet=False, timeout=None):
+    return sendHTTPRequest(
+        node,
+        "remote/cluster_start",
+        printResult=False,
+        printSuccess=not quiet,
+        timeout=timeout
+    )
 
 def stopPacemaker(node, quiet=False, force=True):
     return stopCluster(
@@ -328,7 +342,7 @@ def resumeConfigSyncing(node):
     data = urllib_urlencode({"sync_thread_resume": 1})
     return sendHTTPRequest(node, "remote/set_sync_options", data, False, False)
 
-def canAddNodeToCluster(node_communicator, node):
+def canAddNodeToCluster(node_communicator, target):
     """
     Return tuple with two parts. The first part is information if the node can
     be added to a cluster. The second part is a relevant explanation for first
@@ -338,7 +352,9 @@ def canAddNodeToCluster(node_communicator, node):
     NodeAddresses node contain destination for request
     """
     report_list = []
-    check_can_add_node_to_cluster(node_communicator, node, report_list)
+    com_cmd = PrecheckNewNode(report_list, availability_checker_node)
+    com_cmd.add_request(target)
+    run_com_cmd(node_communicator, com_cmd)
 
     analyzer = ReportListAnalyzer(report_list)
     if not analyzer.error_list:
@@ -383,8 +399,7 @@ def addLocalNode(node, node_to_add, ring1_addr=None):
         except ValueError:
             return 1, output
         return retval2, output
-    else:
-        return 1, output
+    return 1, output
 
 def removeLocalNode(node, node_to_remove, pacemaker_remove=False):
     data = urllib_urlencode({'remove_nodename':node_to_remove, 'pacemaker_remove':pacemaker_remove})
@@ -395,8 +410,7 @@ def removeLocalNode(node, node_to_remove, pacemaker_remove=False):
         except ValueError:
             return 1,output
         return 0, myout
-    else:
-        return 1, output
+    return 1, output
 
 
 # Send an HTTP request to a node return a tuple with status, data
@@ -411,7 +425,13 @@ def removeLocalNode(node, node_to_remove, pacemaker_remove=False):
 def sendHTTPRequest(
     host, request, data=None, printResult=True, printSuccess=True, timeout=None
 ):
-    url = "https://{host}:2224/{request}".format(host=host, request=request)
+    token_file = read_token_file()
+    port = token_file["ports"].get(host)
+    if port is None:
+        port = settings.pcsd_default_port
+    url = "https://{host}:{port}/{request}".format(
+        host=host, request=request, port=port
+    )
     if "--debug" in pcs_options:
         print("Sending HTTP Request to: " + url)
         print("Data: {0}".format(data))
@@ -432,7 +452,7 @@ def sendHTTPRequest(
 
     output = BytesIO()
     debug_output = BytesIO()
-    cookies = __get_cookie_list(host, readTokens())
+    cookies = __get_cookie_list(host, token_file["tokens"])
     if not timeout:
         timeout = settings.default_request_timeout
     if "--request-timeout" in pcs_options:
@@ -506,9 +526,10 @@ def sendHTTPRequest(
         dummy_errno, reason = e.args
         if "--debug" in pcs_options:
             print("Response Reason: {0}".format(reason))
-        msg = "Unable to connect to {host} ({reason})".format(
-            host=host, reason=reason
-        )
+        msg = (
+            "Unable to connect to {host}, try setting higher timeout in "
+            "--request-timeout option ({reason})"
+        ).format(host=host, reason=reason)
         if printResult:
             print(msg)
         return (2, msg)
@@ -799,9 +820,9 @@ def addNodeToClusterConf(node):
 
     return True
 
-def removeNodeFromCorosync(node):
+def removeNodeFromCorosync(node_expression):
     removed_node = False
-    node0, node1 = parse_multiring_node(node)
+    node0, node1 = parse_multiring_node(node_expression)
 
     corosync_conf = getCorosyncConfParsed()
     for nodelist in corosync_conf.get_sections("nodelist"):
@@ -947,6 +968,13 @@ def get_cluster_conf_cman_options():
 def subprocess_setup():
     signal.signal(signal.SIGPIPE, signal.SIG_DFL)
 
+def touch_cib_file(filename):
+    if not os.path.isfile(filename):
+        try:
+            write_empty_cib(filename)
+        except EnvironmentError as e:
+           err("Unable to write to file: '{0}': '{1}'".format(filename, str(e)))
+
 # Run command, with environment and return (output, retval)
 # DEPRECATED, please use lib.external.CommandRunner via utils.cmd_runner()
 def run(
@@ -960,12 +988,7 @@ def run(
     env_var["LC_ALL"] = "C"
     if usefile:
         env_var["CIB_file"] = filename
-
-        if not os.path.isfile(filename):
-            try:
-                write_empty_cib(filename)
-            except IOError:
-                err("Unable to write to file: " + filename)
+        touch_cib_file(filename)
 
     command = args[0]
     if command[0:3] == "crm" or command in ["cibadmin", "cman_tool", "iso8601"]:
@@ -1020,7 +1043,7 @@ def cmd_runner():
     env_vars.update(os.environ)
     env_vars["LC_ALL"] = "C"
     return CommandRunner(
-        logging.getLogger("old_cli"),
+        logging.getLogger("pcs"),
         get_report_processor(),
         env_vars
     )
@@ -1035,11 +1058,7 @@ def run_pcsdcli(command, data=None):
         env_var["PCSD_NETWORK_TIMEOUT"] = str(pcs_options["--request-timeout"])
     else:
         env_var["PCSD_NETWORK_TIMEOUT"] = str(settings.default_request_timeout)
-    pcs_dir = os.path.realpath(os.path.dirname(sys.argv[0]))
-    if pcs_dir == "/usr/sbin":
-        pcsd_dir_path = settings.pcsd_exec_location
-    else:
-        pcsd_dir_path = os.path.join(pcs_dir, '../pcsd')
+    pcsd_dir_path = settings.pcsd_exec_location
     pcsdcli_path = os.path.join(pcsd_dir_path, 'pcsd-cli.rb')
     gem_home = os.path.join(pcsd_dir_path, 'vendor/bundle/ruby')
     env_var["GEM_HOME"] = gem_home
@@ -1076,7 +1095,7 @@ def run_pcsdcli(command, data=None):
 
 def auth_nodes_do(nodes, username, password, force, local):
     pcsd_data = {
-        'nodes': list(set(nodes)),
+        'nodes': nodes,
         'username': username,
         'password': password,
         'force': force,
@@ -1149,7 +1168,14 @@ def call_local_pcsd(argv, interactive_auth=False, std_in=None):
         print('Please authenticate yourself to the local pcsd')
         username = get_terminal_input('Username: ')
         password = get_terminal_password()
-        auth_nodes_do(["localhost"], username, password, True, True)
+        port = get_terminal_input(
+            'Port (default: {0}): '.format(settings.pcsd_default_port)
+            # default port is not completely correct, because default port from
+            # pcsd will be used
+        )
+        if not port:
+            port = None
+        auth_nodes_do({"localhost": port}, username, password, True, True)
         print()
         code, output = sendHTTPRequest(
             "localhost", "run_pcs", data_send, False, False
@@ -1686,7 +1712,7 @@ def is_etree(var):
     )
 
 # Replace only configuration section of cib with dom passed
-def replace_cib_configuration(dom, cib_upgraded=False):
+def replace_cib_configuration(dom):
     if is_etree(dom):
         #etree returns string in bytes: b'xml'
         #python 3 removed .encode() from byte strings
@@ -1697,11 +1723,7 @@ def replace_cib_configuration(dom, cib_upgraded=False):
         new_dom = dom.toxml()
     else:
         new_dom = dom
-    cmd = ["cibadmin", "--replace", "-V", "--xml-pipe"]
-    if cib_upgraded:
-        print("CIB has been upgraded to the latest schema version.")
-    else:
-        cmd += ["-o", "configuration"]
+    cmd = ["cibadmin", "--replace", "-V", "--xml-pipe", "-o", "configuration"]
     output, retval = run(cmd, False, new_dom)
     if retval != 0:
         err("Unable to update cib\n"+output)
@@ -1878,20 +1900,6 @@ def set_cib_property(prop, value, cib_dom=None):
     if update_cib:
         replace_cib_configuration(crm_config)
 
-def setAttribute(a_type, a_name, a_value, exit_on_error=False):
-    args = ["crm_attribute", "--type", a_type, "--attr-name", a_name,
-            "--attr-value", a_value]
-
-    if a_value == "":
-        args.append("-D")
-
-    output, retval = run(args)
-    if retval != 0:
-        if exit_on_error:
-            err(output)
-        else:
-            print(output)
-
 def getTerminalSize(fd=1):
     """
     Returns height and width of current terminal. First tries to get
@@ -1920,8 +1928,7 @@ def get_terminal_input(message=None):
     try:
         if PYTHON2:
             return raw_input("")
-        else:
-            return input("")
+        return input("")
     except EOFError:
         return ""
     except KeyboardInterrupt:
@@ -2631,14 +2638,13 @@ def is_valid_cib_value(type, value, enum_options=[]):
     type = type.lower()
     if type == "enum":
         return value in enum_options
-    elif type == "boolean":
+    if type == "boolean":
         return is_boolean(value)
-    elif type == "integer":
+    if type == "integer":
         return is_score(value)
-    elif type == "time":
+    if type == "time":
         return get_timeout_seconds(value) is not None
-    else:
-        return True
+    return True
 
 
 def get_cluster_property_default(prop_def_dict, prop):
@@ -2775,13 +2781,13 @@ def get_lib_env():
             err("Unable to read %s: %s" % (conf, e.strerror))
 
     return LibraryEnvironment(
-        logging.getLogger("old_cli"),
+        logging.getLogger("pcs"),
         get_report_processor(),
         user,
         groups,
         cib_data,
         corosync_conf_data,
-        auth_tokens_getter=readTokens,
+        token_file_data_getter=read_token_file,
         request_timeout=pcs_options.get("--request-timeout"),
     )
 
@@ -2800,14 +2806,14 @@ def get_cli_env():
     env = Env()
     env.user = user
     env.groups = groups
-    env.auth_tokens_getter = readTokens
+    env.token_file_data_getter = read_token_file
     env.debug = "--debug" in pcs_options
     env.request_timeout = pcs_options.get("--request-timeout")
     return env
 
 def get_middleware_factory():
     return middleware.create_middleware_factory(
-        cib=middleware.cib(usefile, get_cib, replace_cib_configuration),
+        cib=middleware.cib(filename if usefile else None, touch_cib_file),
         corosync_conf_existing=middleware.corosync_conf_existing(
             pcs_options.get("--corosync_conf", None)
         ),
